<!DOCTYPE TS><TS>
<context>
    <name>EditEvent</name>
    <message>
        <source>Edit Event</source>
        <translation>Editar Evento</translation>
    </message>
    <message>
        <source>Start at:</source>
        <translation>Comienzo:</translation>
    </message>
    <message>
        <source>Action If Previous Event Still Playing</source>
        <translation>Acción si el evento anterior está sonando</translation>
    </message>
    <message>
        <source>Start Immediately</source>
        <translation>Iniciar de inmediato</translation>
    </message>
    <message>
        <source>Make Next</source>
        <translation>Convertir en siguiente</translation>
    </message>
    <message>
        <source>Wait up to</source>
        <translation>Espera hasta</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Reproducir</translation>
    </message>
    <message>
        <source>Segue</source>
        <translation>Segue</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Parar</translation>
    </message>
    <message>
        <source>&amp;Audition</source>
        <translation>Escuc&amp;har</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Pausar</translation>
    </message>
    <message>
        <source>&amp;Stop</source>
        <translation>&amp;Parar</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Iniciar</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;Aceptar</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
    <message>
        <source>Edit Marker</source>
        <translation>Editar marcador</translation>
    </message>
    <message>
        <source>Transition If Previous Cart Ends Before</source>
        <translation>Transición si el cartucho previo termina antes</translation>
    </message>
    <message>
        <source>Edit Track</source>
        <translation>Editar pista</translation>
    </message>
    <message>
        <source>Edit Log Track</source>
        <translation>Editar Pista del Log</translation>
    </message>
    <message>
        <source>Start Transition Type:</source>
        <translation>Tipo de transición inicial:</translation>
    </message>
    <message>
        <source>No Fade at Segue Out</source>
        <translation>No desvanecer al terminar</translation>
    </message>
    <message>
        <source>End</source>
        <translation>Fin</translation>
    </message>
    <message>
        <source>Duplicate Start Time</source>
        <translation>Tiempo de inicio duplicado</translation>
    </message>
    <message>
        <source>An event is already scheduled with this start time!</source>
        <translation>Un evento ha sido programado con esa misma hora de inicio!</translation>
    </message>
</context>
<context>
    <name>ListLog</name>
    <message>
        <source>TIME</source>
        <translation>HORA</translation>
    </message>
    <message>
        <source>TRANS</source>
        <translation>TRANS</translation>
    </message>
    <message>
        <source>CART</source>
        <translation>CARTUCHO</translation>
    </message>
    <message>
        <source>TITLE</source>
        <translation>TÍTULO</translation>
    </message>
    <message>
        <source>ARTIST</source>
        <translation>ARTISTA</translation>
    </message>
    <message>
        <source>CLIENT</source>
        <translation>CLIENTE</translation>
    </message>
    <message>
        <source>AGENCY</source>
        <translation>AGENCIA</translation>
    </message>
    <message>
        <source>LABEL</source>
        <translation>ETIQUETA</translation>
    </message>
    <message>
        <source>LINE ID</source>
        <translation>ID DE LÍNEA</translation>
    </message>
    <message>
        <source>COUNT</source>
        <translation>CUENTA</translation>
    </message>
    <message>
        <source>STATUS</source>
        <translation>ESTADO</translation>
    </message>
    <message>
        <source>Select</source>
        <translation>Seleccionar</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausar</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Parar</translation>
    </message>
    <message>
        <source>Make
Next</source>
        <translation>Hacer
Siguiente</translation>
    </message>
    <message>
        <source>Modify</source>
        <translation>Modificar</translation>
    </message>
    <message>
        <source>Scroll</source>
        <translation>Desplazar</translation>
    </message>
    <message>
        <source>Select
Log</source>
        <translation>Elegir
Lista</translation>
    </message>
    <message>
        <source>Log Exists</source>
        <translation>La lista ya existe</translation>
    </message>
    <message>
        <source>Log Already Exists!</source>
        <translation>¡La lista de reproducción ya existe!</translation>
    </message>
    <message>
        <source>--- end of log ---</source>
        <translation>--- fin de la lista ---</translation>
    </message>
    <message>
        <source>PLAY</source>
        <translation>REPRO</translation>
    </message>
    <message>
        <source>STOP</source>
        <translation>PARAR</translation>
    </message>
    <message>
        <source>SEGUE</source>
        <translation>SEGUE</translation>
    </message>
    <message>
        <source>MARKER</source>
        <translation>MARCADOR</translation>
    </message>
    <message>
        <source>CHAIN TO</source>
        <translation>ENCADENAR A</translation>
    </message>
    <message>
        <source>[CART NOT FOUND]</source>
        <translation>[CARTUCHO NO ENCONTRADO]</translation>
    </message>
    <message>
        <source>[NO VALID CUT AVAILABLE]</source>
        <translation>[NO HAY AUDIOS VÁLIDOS]</translation>
    </message>
    <message>
        <source>T</source>
        <translation>T</translation>
    </message>
    <message>
        <source>[NO AUDIO AVAILABLE]</source>
        <translation>[NO HAY AUDIO DISPONIBLE]</translation>
    </message>
    <message>
        <source>TRACK</source>
        <translation>PISTA</translation>
    </message>
    <message>
        <source>LEN</source>
        <translation>LONG</translation>
    </message>
    <message>
        <source>LINK</source>
        <translation>ENLACE</translation>
    </message>
    <message>
        <source>[music import]</source>
        <translation>[importar música]</translation>
    </message>
    <message>
        <source>[traffic import]</source>
        <translation>[importar tráfico]</translation>
    </message>
    <message>
        <source>EST TIME</source>
        <translation>TIEMPO EST</translation>
    </message>
    <message>
        <source>GROUP</source>
        <translation>GRUPO</translation>
    </message>
    <message>
        <source>Refresh
Log</source>
        <translation>Actualizar
Lista</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Empezar</translation>
    </message>
    <message>
        <source>Run Length</source>
        <translation>Duración</translation>
    </message>
    <message>
        <source>Next Stop:</source>
        <translation>Próximo:</translation>
    </message>
    <message>
        <source>Log End:</source>
        <translation>Fin de PL:</translation>
    </message>
    <message>
        <source>Selected:</source>
        <translation>Selecc.:</translation>
    </message>
    <message>
        <source>Audition
Head</source>
        <translation>Escuchar
Comienzo</translation>
    </message>
    <message>
        <source>Audition
Tail</source>
        <translation>Escuchar
Final</translation>
    </message>
</context>
<context>
    <name>ListLogs</name>
    <message>
        <source>Select a Log</source>
        <translation>Seleccione una lista</translation>
    </message>
    <message>
        <source>NAME</source>
        <translation>NOMBRE</translation>
    </message>
    <message>
        <source>DESCRIPTION</source>
        <translation>DESCRIPCIÓN</translation>
    </message>
    <message>
        <source>SERVICE</source>
        <translation>SERVICIO</translation>
    </message>
    <message>
        <source>Load</source>
        <translation>Cargar</translation>
    </message>
    <message>
        <source>Unload</source>
        <translation>Descargar</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Guardar</translation>
    </message>
    <message>
        <source>Save &amp;As</source>
        <translation>Gu&amp;ard. como</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Rename Log</source>
        <translation>Cambiar nombre de la lista</translation>
    </message>
</context>
<context>
    <name>LogLineBox</name>
    <message>
        <source>STOP</source>
        <translation>PARAR</translation>
    </message>
    <message>
        <source>PLAY</source>
        <translation>REPRO</translation>
    </message>
    <message>
        <source>SEGUE</source>
        <translation>SEGUE</translation>
    </message>
    <message>
        <source>[CART NOT FOUND]</source>
        <translation>[CARTUCHO NO ENCONTRADO]</translation>
    </message>
    <message>
        <source>[NO AUDIO AVAILABLE]</source>
        <translation>[NO HAY AUDIO DISPONIBLE]</translation>
    </message>
    <message>
        <source>[NO VALID CUT AVAILABLE]</source>
        <translation>[NO HAY CUTS DISPONIBLES]</translation>
    </message>
    <message>
        <source>MARKER</source>
        <translation>MARCADOR</translation>
    </message>
    <message>
        <source>T</source>
        <translation>T</translation>
    </message>
    <message>
        <source>TRACK</source>
        <translation>PISTA</translation>
    </message>
    <message>
        <source>CHAIN</source>
        <translation>CADENA</translation>
    </message>
    <message>
        <source>LINK</source>
        <translation>ENLACE</translation>
    </message>
    <message>
        <source>[music import]</source>
        <translation>[importar música]</translation>
    </message>
    <message>
        <source>[traffic import]</source>
        <translation>[importar tráfico]</translation>
    </message>
</context>
<context>
    <name>MainWidget</name>
    <message>
        <source>Main Log</source>
        <translation>Lista ppal</translation>
    </message>
    <message>
        <source>Aux 1 Log</source>
        <translation>Lista aux. 1</translation>
    </message>
    <message>
        <source>Aux 2 Log</source>
        <translation>Lista aux. 2</translation>
    </message>
    <message>
        <source>Exit RDAirPlay?</source>
        <translation>¿Salir de RDAirPlay?</translation>
    </message>
    <message>
        <source>RDAirPlay - Host:</source>
        <translation>RDAirPlay - Equipo:</translation>
    </message>
    <message>
        <source>Database Error</source>
        <translation>Error en la base de datos</translation>
    </message>
    <message>
        <source>ADD</source>
        <translation>AÑADIR</translation>
    </message>
    <message>
        <source>DEL</source>
        <translation>QUITAR</translation>
    </message>
    <message>
        <source>MOVE</source>
        <translation>MOVER</translation>
    </message>
    <message>
        <source>COPY</source>
        <translation>COPIAR</translation>
    </message>
    <message>
        <source>Main Log
[--]</source>
        <translation>Lista ppal.
[--]</translation>
    </message>
    <message>
        <source>Aux 1 Log
[--]</source>
        <translation>Lista aux. 1
[--]</translation>
    </message>
    <message>
        <source>Aux 2 Log
[--]</source>
        <translation>Lista aux. 2
[--]</translation>
    </message>
    <message>
        <source>Sound
Panel</source>
        <translation>Panel de
sonidos</translation>
    </message>
    <message>
        <source>RDAirPlay</source>
        <translation>RDAirPlay</translation>
    </message>
    <message>
        <source>Multiple instances not allowed!</source>
        <translation>¡No se permiten múltiples instancias!</translation>
    </message>
    <message>
        <source>LOG
REFRESHING</source>
        <translation>LEYENDO
LISTA</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>Usuario:</translation>
    </message>
    <message>
        <source>Log:</source>
        <translation>Lista:</translation>
    </message>
    <message>
        <source>Service:</source>
        <translation>Servicio:</translation>
    </message>
</context>
<context>
    <name>ModeDisplay</name>
    <message>
        <source>Operating Mode</source>
        <translation>Modo de operación</translation>
    </message>
    <message>
        <source>LiveAssist</source>
        <translation>Asist. en Vivo</translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation>Automatico</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manual</translation>
    </message>
</context>
<context>
    <name>PostCounter</name>
    <message>
        <source>On Time</source>
        <translation>A tiempo</translation>
    </message>
    <message>
        <source>Next Timed Start</source>
        <translation>Sig. Inicio Programado</translation>
    </message>
    <message>
        <source>Next Timed Start [--:--:--]</source>
        <translation>Sig. Inicio Programado [--:--:--]</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>START</source>
        <translation>INICIAR</translation>
    </message>
    <message>
        <source>STOP</source>
        <translation>PARAR</translation>
    </message>
    <message>
        <source>PAUSE</source>
        <translation>PAUSA</translation>
    </message>
    <message>
        <source>RESUME</source>
        <translation>SEGUIR</translation>
    </message>
    <message>
        <source>WHERE?</source>
        <translation>¿DÓNDE?</translation>
    </message>
    <message>
        <source>DELETE?</source>
        <translation>¿BORRAR?</translation>
    </message>
    <message>
        <source>MOVE?</source>
        <translation>¿MOVER?</translation>
    </message>
    <message>
        <source>TO?</source>
        <translation>¿HACIA?</translation>
    </message>
    <message>
        <source>COPY?</source>
        <translation>¿COPIAR?</translation>
    </message>
    <message>
        <source>ERROR</source>
        <translation>ERROR</translation>
    </message>
</context>
<context>
    <name>StopCounter</name>
    <message>
        <source>Next Stop [none]</source>
        <translation>Prox parada [ninguna]</translation>
    </message>
    <message>
        <source>Next Stop</source>
        <translation>Prox parada</translation>
    </message>
    <message>
        <source>Stopped</source>
        <translation>Detenido</translation>
    </message>
</context>
</TS>
